<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://selmamariudottir.com
 * @since      1.0.0
 *
 * @package    Wp_Date_Remover
 * @subpackage Wp_Date_Remover/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wp_Date_Remover
 * @subpackage Wp_Date_Remover/admin
 * @author     Selma Mariudottir <selma@selmamariudottir.com>
 */
class Wp_Date_Remover_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Date_Remover_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Date_Remover_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wp-date-remover-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Date_Remover_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Date_Remover_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wp-date-remover-admin.js', array( 'jquery' ), $this->version, false );

	}
	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	 
	public function add_plugin_admin_menu() {
	
		/*
		 * Add a settings page for this plugin to the Settings menu.
		 *
		 * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
		 *
		 *        Administration Menus: http://codex.wordpress.org/Administration_Menus
		 *
		 */
		add_options_page( 'WP Date Remover', 'WP Date Remover', 'manage_options', $this->plugin_name, array($this, 'wp_date_remove_settings')
		);
	}
	
	 /**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */
	 
	public function add_action_links( $links ) {
		/*
		*  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
		*/
	   $settings_link = array(
		'<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __('Settings', $this->plugin_name) . '</a>',
	   );
	   return array_merge(  $settings_link, $links );
	
	}
	
	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */
	 
	public function wp_date_remove_settings() {
		include_once( 'partials/wp-date-remover-admin-display.php' );
	}
	
	public function options_update() {
		register_setting($this->plugin_name, $this->plugin_name, array($this, 'validate'));
	}
	 
	public function validate($input) {
		// All checkboxes inputs        
		$valid = array();
		
		$wdr_args = array(
		  'orderby' => 'name',
		  'order' => 'ASC'
		  );
    	$wdr_categories = get_categories($wdr_args);
		if(is_array($wdr_categories) && !empty($wdr_categories))
		{
			foreach($wdr_categories as $wdr_cat)
			{
				$wdr_i++;
				$valid['removedt_'.$wdr_cat->term_id] = (isset($input['removedt_'.$wdr_cat->term_id]) && !empty($input['removedt_'.$wdr_cat->term_id])) ? 1 : 0;
			}
		}
		
		return $valid;
	 }

	public function wp_date_remover_add_notice()
    {
		include_once( 'partials/wp-date-remover-admin-display-notice.php' );
    }

	public function wp_date_remover_hide_notice()
	{
		update_option("wdr_admin_notices_show", 0);
	}


}
