<?php
/**
 * Widget API: Karen_Widget_Twitter class
 * This widget is depend on Twitter oAuth for developer plugin which is recommended via TGMPA.  
 *
 * @package Karen
 * @since 0.1.0
 */

class Karen_Widget_Twitter extends WP_Widget {
	/**
	 * Sets up a new Recent Tweet widget instance.
	 *
	 * @since 0.1.0
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array('classname' => 'widget-twitter', 'description' => __( "Twitter Feed.", 'karen') );
		parent::__construct('karen-twitter', __('Karen - Twitter', 'karen'), $widget_ops);
		$this->alt_option_name = 'widget_twitter';
	}

	/**
	 * Outputs the content for the current Recent Tweet widget instance.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */	
	function widget($args, $instance) {		
		extract( $args );
		$default = array ( 'widget_title'=>__('Latest Tweet', 'karen'), 'id'=>'', 'qty'=>5 );
		$instance = wp_parse_args($instance, $default);			
		$widget_title = apply_filters('widget_title', $instance['widget_title'], $instance, $this->id_base);
		$id = $instance['id'];
		$qty = $instance['qty'];

		echo $before_widget;

		if(!empty($widget_title)){ echo $before_title . $widget_title . $after_title; }

		if ( function_exists('getTweets') ){
			$tweets = getTweets( $id, $qty);

			if (empty($tweets['errors']) ){
				echo '<div class="twitter-update-list">';
				
				foreach( $tweets as $tweet ){
					$text = $this->autolink($tweet['text']);
					$text = preg_replace('/(^|\s)@(\w+)/', '\1@<a href="http://www.twitter.com/\2">\2</a>', $text);
					$text = preg_replace('/(^|\s)#(\w+)/', '\1#<a href="http://search.twitter.com/search?q=%23\2">\2</a>', $text);

					printf( '<div class="tweet"><div class="tweet-meta"><a href="http://twitter.com/%1$s/statuses/%2$s">%3$s</a></div><p class="icon-twitter">%4$s</p></div>',
						esc_attr( $id ),
						$tweet['id_str'],
						$this->relative_time( strtotime( $tweet['created_at'] ) ),
						$text );
	
				}
				echo '</div>';
			}else{
				echo '<ul id="twitter_update_list"><li>' . __('Cannot fetch tweets', 'karen') . '</li></ul>';
			}
		}
		?>
		<div id="twitter-account">
			<?php if (isset($tweets[0]['user']['profile_image_url'])) : ?>
        	<a  rel="nofollow" href="<?php echo esc_url( 'http://www.twitter.com/'.  $id ); ?>">
        		<img src="<?php echo esc_url( $tweets[0]['user']['profile_image_url']); ?>" alt="<?php esc_attr_e('Twitter Profile Picture', 'karen'); ?>"  />
        	</a>
        <?php endif; ?>
			<span class="entry-meta"><?php _e('Follow', 'karen'); ?></span>
			@<a  rel="nofollow" href="<?php echo esc_url( 'http://www.twitter.com/'.  $id ); ?>"><?php echo esc_html($id) ?></a>
		</div>
		<?php
		echo $after_widget;		
	}

	/**
	 * Handles updating the settings for the current Recent Tweets widget instance.
	 *
	 * @since 0.1.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	function update($new_instance, $old_instance) {				
		$instance = $old_instance;
		$instance['widget_title'] = sanitize_text_field( $new_instance['widget_title'] );
		$instance['id'] = sanitize_text_field( $new_instance['id'] );
		$instance['qty'] = (int) $new_instance['qty'];

		return $instance;
	}

	/**
	 * Outputs the settings form for the Recent Tweets widget.
	 *
	 * @since 0.1.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	function form($instance) {	
		$default = array ( 'widget_title'=>__('Latest Tweet', 'karen'), 'id'=>'', 'qty'=>5 );
		$instance = wp_parse_args($instance, $default);			
		$widget_title = $instance['widget_title'];
		$id = $instance['id'];
		$qty = $instance['qty'];
	?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Widget title:', 'karen' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" type="text" name="<?php echo $this->get_field_name('widget_title'); ?>" value="<?php echo esc_attr( $widget_title ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'id' ); ?>"><?php _e( 'Enter ID of your twitter account', 'karen' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'id' ); ?>" type="text" name="<?php echo $this->get_field_name('id'); ?>" value="<?php echo esc_attr( $id ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'qty' ); ?>"><?php _e( 'Number of tweets', 'karen' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'qty' ); ?>" type="text" name="<?php echo $this->get_field_name('qty'); ?>" value="<?php echo esc_attr( $qty ); ?>" />
		</p>

	<?php
	}

	/*
	 * Function relative time
	 *
	 */
	function relative_time($time = false, $limit = 86400, $format = 'g:i A M jS') {
		if (empty($time) || (!is_string($time) && !is_numeric($time))) $time = time();
		elseif (is_string($time)) $time = strtotime($time);

		$now = time();
		$relative = '';

		if ($time === $now) $relative = __('now', 'karen');
		elseif ($time > $now) $relative = __('in the future', 'karen');
		else {
			$diff = $now - $time;

			if ($diff < 60) {
				$relative = __('Less than one minute ago', 'karen');
			} elseif (($minutes = ceil($diff/60)) < 60) {
				if ( (int)$minutes === 1 ) {
					$relative = __( 'A Minute ago', 'karen');
				} else {
					$relative = $minutes . __(' Minutes ago', 'karen' );	
				}
			} elseif ( $diff < (24*60*60) ){
				$hours = ceil($diff/3600);
				if ( (int)$hours === 1 ) {
					$relative = __( 'An Hour ago', 'karen');
				} else {
					$relative = $hours . __(' Hours ago', 'karen' );	
				}
			}elseif ( $diff < (48*60*60) ){
				$hours = ceil($diff/3600);
				$relative = __('1 Day ago', 'karen');
			}else{
				$relative = ceil($diff / 86400) . __( ' Days ago', 'karen' );
			}
		}

		return $relative;
	}

	function autolink($str, $attributes=array()) {
		$attrs = '';
		foreach ($attributes as $attribute => $value) {
			$attrs .= " {$attribute}=\"{$value}\"";
		}

		$str = ' ' . $str;
		$str = preg_replace(
			'`([^"=\'>])((http|https|ftp)://[^\s<]+[^\s<\.)])`i',
			'$1<a href="$2"'.$attrs.'>$2</a>',
			$str
		);
		$str = substr($str, 1);
		
		return $str;
	}

	
}

function karen_register_widget_twitter() {
	return register_widget("Karen_Widget_Twitter");	
}

add_action('widgets_init', 'karen_register_widget_twitter');

?>